[![Version](https://img.shields.io/badge/npm-1.1.3-red?link=https%3A%2F%2Fwww.npmjs.com%2Fpackage%2Fcss-injector)](https://www.npmjs.com/package/ml-css-injector) [![Static Badge](https://img.shields.io/badge/Mobiloud-%23047857?link=https%3A%2F%2Fwww.mobiloud.com%2F)](https://www.mobiloud.com/)


# MobiLoud CSS Injector

CSS injector with regex functionality


## Features

CSS Injector features:
- Inject CSS in your site globally selectively for your pages with regex
- os method available: its a function that can be called to get the current browser OS, useful for triggering external functions'. It returns a string containing "android" | "ios" | "windows" | "desktop"
- isMobile, isCanvas exposed for filtering 
- Code written in Typescript and minified/bundled with Vite


## 📖 How to use

CSS Injector can be used importing the JS code via CDN or as a module using NPM

### 🚀 With CDN

```javascript
<script src="https://cdn.jsdelivr.net/npm/ml-css-injector/dist/ml-css-injector.min.js"></script>
<script>
    (function(){
      addStyle({css: `a{color: red !important}`});
      addStyle({css: `a{color: yellow !important}`, regex: /\/\?param$/});
      addStyle({css: `a{color: green !important}`, regex: /.*/, name: "Global Styles"});
      addStyle({css: `a{color: green !important}`, regex: /.*/, name: "Global Styles", logs: true});
    })()
  </script>

```
## Configuration options: 

```typescript

// accepts any styles as a string

let style = `
a{
  color: green;
  background-color: yellow
} 
.className {
  font-size: 2rem
}
`
// accepts regex enclosed within slashes
let regex = /.*/

// accepts string
let name = "Style name"

//boolean --> Prints logs in console for debugging

addStyle({css: string, regex: string, name: string, logs: boolean});
addStyle({css: `color: red !important`}) // if no regex passed, the styles applies to every page

```

## Recipe for multiple styles:

```typescript

// accepts any styles as a string

let styles = [
  {
    css: `
          a{
            color: green;
            background-color: yellow
          } 
          `,
    regex: /.*/,
    name: "Global Styles"
  },
  {
    css: `
          .cart{
            color: green;
            background-color: yellow
          } 
          `,
    regex: /.*\/cart/,
    name: "Cart page"
  },
  {
    css: "div.login{display: none}",
    regex: /.*\/login/,
    name: "Login page"
  }
]
// accepts regex enclosed within slashes

styles.forEach(e => { 
    addStyle({
      css: e.css,
      regex: e.regex,
      name: e.name,
      logs: true
    })
} )


```



## Methods


```javascript
deviceData.os // returns current os "android" | "ios" | "windows" | "desktop"
deviceData.isCanvas // returns true or false
deviceData.isMobile // returns true or false
```

## Development

- `npm run build` produces a production version into /dist folder
- `npm run dev` runs dev version and starts a dev server


## Testing the Injector

You will definitely want to test the CSS Injector once you deploy them to your website, to make sure that everything works and looks as you want.

Running these tests on real mobile devices can get overwhelming, so we recommend that you run your tests on your desktop browser.

To do this, you will need to emulate a mobile device by adjusting your [browser’s user agent](https://developer.mozilla.org/en-US/docs/Glossary/User_agent). We recommend using the following Chrome extension to do this: [User Agent Switcher and Manager](https://chrome.google.com/webstore/detail/user-agent-switcher-and-m/bhchdcejhohfmigjafbampogmaanbfkg)

Once you have installed the extension, set it up as follows:

### **Step 1**

Select “Chrome” as the browser and “Android” as the platform if you want to test the Android version of the Button, or “Safari” and “iOS” in case you want to test the iOS version:

![annotely_image (61).png](https://mobiloud.notion.site/image/https%3A%2F%2Fs3-us-west-2.amazonaws.com%2Fsecure.notion-static.com%2F3c66d89a-b74e-441a-a15f-197d08f78807%2Fannotely_image_(61).png?table=block&id=7b5f225a-60e2-4001-bcdb-e4627b300be4&spaceId=f1cb51a8-e748-4832-9335-2c96a2e81d09&width=1230&userId=&cache=v2)

### **Step 2**

Select one of the options that will appear, any will work:

![annotely_image (62).png](https://mobiloud.notion.site/image/https%3A%2F%2Fs3-us-west-2.amazonaws.com%2Fsecure.notion-static.com%2Fdec5d36c-69ec-40f5-aaf9-d4cc54e1e972%2Fannotely_image_(62).png?table=block&id=dd116c73-51a6-449f-b34c-03358baadb92&spaceId=f1cb51a8-e748-4832-9335-2c96a2e81d09&width=1230&userId=&cache=v2)

### **Step 3**

Click “Apply” to make sure the user agent is properly set up on your browser:

![annotely_image (63).png](https://mobiloud.notion.site/image/https%3A%2F%2Fs3-us-west-2.amazonaws.com%2Fsecure.notion-static.com%2Fcb126a7c-e078-4250-889c-83653ce496dd%2Fannotely_image_(63).png?table=block&id=eae2261a-b36c-43b3-b151-2c02fc4ac39a&spaceId=f1cb51a8-e748-4832-9335-2c96a2e81d09&width=1230&userId=&cache=v2)

### Step 4

You can now press “F5” while viewing your website to refresh the browser window with the updated user agent.

### Reset

If you want to revert the changes to the user agent, as some websites might start behaving differently after doing so, you can click the “Reset” button:

![annotely_image (64).png](https://mobiloud.notion.site/image/https%3A%2F%2Fs3-us-west-2.amazonaws.com%2Fsecure.notion-static.com%2F8af461b2-d9a7-43bf-9d0a-bec281b98347%2Fannotely_image_(64).png?table=block&id=9e9c3806-30d7-495e-820c-bfca7d0e8331&spaceId=f1cb51a8-e748-4832-9335-2c96a2e81d09&width=1230&userId=&cache=v2)

## License

Copyright (c) MobiLoud
